==> CloudManagerStandardAWS_v2.0.1.tar.gz: cloud_manager_base-2.0.1/com/clustercontrol/cloud/commons/CloudConstants.java <==
/*
Copyright (C) 2013 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.
 */
package com.clustercontrol.cloud.commons;

import java.text.DateFormat;
import java.text.SimpleDateFormat;

public interface CloudConstants {
	public static final String pluginId_billing_alarm = "CLOUD_BILLING_ALARM"; 

	public static final String NT_AccountResource = "AccountResource";
	public static final String NT_Resource = "Resource";

	public static final String CONSTANT_TEMPLATE_JOB_PARAMETER_PREFIX = "cloud_";
	public static final String CONSTANT_TEMPLATE_SCRIPT_FILE_PATH = "./var/cloud/";
	
	public final static DateFormat time_format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

	// ノードを追加した際のイベント
	public static final String Node_AccountResource = "Node_AccountResource";

	public static final String Node_Instance_Add = "Node_Instance_Add";
	public static final String Node_Instance_Modify = "Node_Instance_Modify";
	public static final String Node_Instance_Clear = "Node_Instance_Clear";

	public static final String Node_Cloud_Add = "Node_Cloud_Add";

	public static final String Node_CloudAccountResourceScope_Add = "Node_CloudAccountResourceScope_Add";
}

==> CloudManagerStandardAWS_v2.0.3.tar.gz: cloud_manager_base-2.0.3/com/clustercontrol/cloud/commons/CloudConstants.java <==
/*
Copyright (C) 2014 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.
 */
package com.clustercontrol.cloud.commons;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.regex.Pattern;

public interface CloudConstants {
	public static final String pluginId_billing_alarm = "CLOUD_BILLING_ALARM"; 

	public static final String NT_AccountResource = "AccountResource";
	public static final String NT_Resource = "Resource";

	public static final String CONSTANT_TEMPLATE_JOB_PARAMETER_PREFIX = "cloud_";
	public static final String CONSTANT_TEMPLATE_SCRIPT_FILE_PATH = "./var/cloud/";
	
	public final static DateFormat time_format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
	public final static Pattern time_pattern = Pattern.compile("^[0-9]{4}+-[0-9]{2}+-[0-9]{2}+ [0-9]{2}+:[0-9]{2}+:[0-9]{2}+$");

	// ノードを追加した際のイベント
	public static final String Node_AccountResource = "Node_AccountResource";

	public static final String Node_Instance_Add = "Node_Instance_Add";
	public static final String Node_Instance_Modify = "Node_Instance_Modify";
	public static final String Node_Instance_Clear = "Node_Instance_Clear";

	public static final String Node_Cloud_Add = "Node_Cloud_Add";

	public static final String Node_CloudAccountResourceScope_Add = "Node_CloudAccountResourceScope_Add";

	// 機能ID
	public static final String FT_CloudServiceBilling = "com.clustercontrol.cloud.base.function.CloudServiceBilling";
}
